@@ -20,6 +20,10 @@ sub index_template_file {
     $self->spew_as_template($file, $body);
 }
 
+sub required_modules {
+    'Nephia::View::Xslate' => '0',
+}
+
 1;
 
 __DATA__
@@ -73,17 +77,6 @@ it under the same terms as Perl itself.
 :::cut
 ===
 
-cpanfile
----
-requires 'Nephia' => '0';
-requires 'Nephia::View::Xslate' => '0';
-
-on build => sub {
-    requires 'Test::More';
-};
-
-===
-
 common_conf
 ---
 +{
